summaryrefslogtreecommitdiffstats
path: root/forms/source/richtext/parametrizedattributedispatcher.hxx
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-07 11:47:06 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-07 11:47:06 +0000
commit8ceff95c69cf9bd9ff5ab3a4b5689925b8bd6a59 (patch)
treeca2b0cc4fba88107f5f6e740285184a061011866 /forms/source/richtext/parametrizedattributedispatcher.hxx
parentAdding debian version 4:24.2.3-2. (diff)
downloadlibreoffice-8ceff95c69cf9bd9ff5ab3a4b5689925b8bd6a59.tar.xz
libreoffice-8ceff95c69cf9bd9ff5ab3a4b5689925b8bd6a59.zip
Merging upstream version 4:24.2.4.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'forms/source/richtext/parametrizedattributedispatcher.hxx')
-rw-r--r--forms/source/richtext/parametrizedattributedispatcher.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/forms/source/richtext/parametrizedattributedispatcher.hxx b/forms/source/richtext/parametrizedattributedispatcher.hxx
index 6984473161..8a68486c13 100644
--- a/forms/source/richtext/parametrizedattributedispatcher.hxx
+++ b/forms/source/richtext/parametrizedattributedispatcher.hxx
@@ -21,7 +21,7 @@
#include "attributedispatcher.hxx"
-class SfxPoolItem;
+class SfxPoolItemHolder;
namespace frm
{
@@ -47,10 +47,10 @@ namespace frm
protected:
// own overridables
/** convert the arguments as got in a XDispatch::dispatch call into an SfxPoolItem, which can
be used with a IMultiAttributeDispatcher::executeAttribute
*/
- virtual const SfxPoolItem* convertDispatchArgsToItem(
+ virtual SfxPoolItemHolder convertDispatchArgsToItem(
const css::uno::Sequence< css::beans::PropertyValue >& _rArguments );
};
@@ -47,10 +47,10 @@ namespace frm
protected:
// own overridables
- /** convert the arguments as got in a XDispatch::dispatch call into an SfxPoolItem, which can
+ /** convert the arguments as got in a XDispatch::dispatch call into an SfxPoolItemHolder, which can
be used with a IMultiAttributeDispatcher::executeAttribute
*/